@@ -1,4 +1,4 @@
-# Copyright 2015-2016 F-Secure
+# Copyright 2015-2017 F-Secure
 
 # Licensed under the Apache License, Version 2.0 (the "License"); you
 # may not use this file except in compliance with the License.  You may
@@ -11,6 +11,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 # implied.  See the License for the specific language governing
 # permissions and limitations under the License.
+import os
+import time
 
 import xml.etree.ElementTree as etree
 
@@ -37,3 +39,9 @@ def subelement(element, xpath, tag, text, **kwargs):
         subelm.set(attr, value)
 
     return subelm
+
+
+def tag_disk(disk):
+    with open('{}.{}'.format(os.path.realpath(disk), 'lastaccess'), 'w') as touch:
+        touch.write(str(time.time()))
+        touch.truncate()
