@@ -1,4 +1,4 @@
-# Copyright 2015-2016 F-Secure
+# Copyright 2015-2017 F-Secure
 
 # Licensed under the Apache License, Version 2.0 (the "License"); you
 # may not use this file except in compliance with the License.  You may
@@ -17,6 +17,7 @@ This provider does nothing but return the configured image URI string as is.
 
 """
 
+import os
 from see.interfaces import ImageProvider
 
 
@@ -27,4 +28,4 @@ class DummyProvider(ImageProvider):
 
     @property
     def image(self):
-        return self.uri
+        return os.path.join(self.configuration.get('path'), self.name)
